##  Applying Filters
You can filter data based on specific criteria, such as relations to business capability, IT component, application and more. This allows you to create customized views and narrow down scope by focusing on specific technologies or applications within the report.
Filters can be applied using either the filter bar at the top or the filter facets on the left-hand side, which appear when hovering the mouse pointer on the left side of the window. For more information on applying Filters, see [Applying Filter in Reports](https://help.sap.com/docs/leanix/ea/using-reports?locale=en-US&state=PRODUCTION&version=CLOUD).
**Note**
'OR' operator for filtering is currently not supported in radar reports.
